%define ALD_Ver		2.0
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

Name:         nfs-utils

License:      MIT and GPLv2 and GPLv2+ and BSD
Summary:      Linux NFS utility package.
Version:      2.4.3
Release:      0
URL: https://www.kernel.org/pub/linux/utils/nfs-utils/

Source: %{name}-%{version}.tar.xz

%define DestDir		/net
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
Minimal NFS utilities only supporting client
#-------------------------------
%package nfsd
Summary:      NFS Server utilities 
%description nfsd
NFS Server utilities
#-------------------------------
%package tools
Summary:      NFS tools nfsconf, nfsstat, rpcdebug
%description tools
NFS tools nfsconf, nfsstat, rpcdebug

#-------------------------------
%package python
Summary:      python for %{name}
%description python
python for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -O2 -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables"

CFLAGS="$OPTFLAGS -std=gnu99"
CXXFLAGS="$OPTFLAGS"
LDFLAGS="-Wl,--gc-sections"

%configure \
	--disable-gss \
	--enable-mountconfig \
	--enable-shared \
	--disable-static \
	--disable-libtool-lock \
	--disable-nfsv4 \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/defaults

make DESTDIR=$RPM_BUILD_ROOT install &>Finstall_log.txt
cp -a nfs.conf $RPM_BUILD_ROOT%{_sysconfdir}/defaults/
cp -a utils/mount/nfsmount.conf $RPM_BUILD_ROOT%{_sysconfdir}/defaults/

cp README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

rm $RPM_BUILD_ROOT%{_sbindir}/start-statd
rm $RPM_BUILD_ROOT%{_mandir}/man7/nfs.systemd.7

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Post -------------------------------------------
%posttrans
if test ! -e /etc/nfs.conf ; then
  cp -a /etc/defaults/nfs.conf /etc/nfs.conf
fi

if test ! -e /etc/init.d/nfs ; then
  mkdir -p /etc/init.d/rc_net
  cat > /etc/init.d/nfs <<EOF
#!/bin/bash

. /etc/colorrc

test -f /etc/aldccp/network || exit 0
. /etc/aldccp/network

test -f /usr/sbin/rpc.statd || exit 0

case "\$1" in
    start)
	if test x\$NETWORKING = x"yes" -a x\$NFS_START = x"yes"; then
	  if ! checkproc /sbin/rpcbind; then
	      echo "/sbin/rpcbind: is not running \$rc_Err"
	      exit 1
	  fi

	  sm-notify

	  if ! checkproc /usr/sbin/rpc.statd; then
	      echo -n "Starting rpc.statd daemon... "
	      rpc.statd --no-notify
	      if test \$? != 0; then
		  echo "\$rc_Err"
		  exit 1
	      fi
	      echo "\$rc_Ok"
	  fi
	fi
	;;
    stop)
	if test -e /var/lib/nfs/.etab.lock -o -e /var/lib/nfs/.xtab.lock; then
	  exit 0
	fi

	if checkproc /usr/sbin/rpc.statd; then
	    echo -n "Shut Down rpc.statd daemon... "
	    killproc rpc.statd
	    if test \$? != 0; then
		echo "\$rc_Err"
	    else
		echo "\$rc_Ok"
	    fi
	fi
	;;
    restart)
	\$0 stop
	\$0 start
	;;
    *)
	echo "Usage: {start|stop|restart}"
	exit 1
	;;
esac

exit 0

EOF

  chmod 0740 /etc/init.d/nfs

  pushd /etc/init.d/rc_net >/dev/null
    ln -s ../nfs K11nfs
    ln -s ../nfs S83nfs
  popd >/dev/null

fi


%posttrans nfsd
if test ! -e /etc/exports ; then
  cat > /etc/exports <<EOF
# Please read the manual page exports(5) for more information.

# sample /etc/exports file

#/tmp            *(ro,all_squash,subtree_check)
#/               master(rw) trusty(rw,no_root_squash)
#/projects       proj*.local.domain(rw)
#/usr            *.local.domain(ro) @trusted(rw)
#/home/joe       pc001(rw,all_squash,anonuid=150,anongid=100)
#/pub            *(ro,insecure,all_squash)
#/srv/www        -sync,rw server @trusted @external(ro)
/                192.168.*.*(ro,no_subtree_check,no_root_squash)

EOF
fi

if test ! -e /etc/nfsmount.conf ; then
  cp -a /etc/defaults/nfsmount.conf /etc/nfsmount.conf
fi


if test ! -e /etc/init.d/nfsd ; then
  mkdir -p /etc/init.d/rc_net

  cat > /etc/init.d/nfsd <<EOF
#!/bin/bash

. /etc/colorrc

test -f /etc/aldccp/network || exit 0
. /etc/aldccp/network

test -f /usr/sbin/exportfs || exit 0
test -f /usr/sbin/rpc.mountd || exit 0
test -f /usr/sbin/rpc.statd || exit 0
test -f /usr/sbin/rpc.nfsd || exit 0

case "\$1" in
    start)
	if test x\$NETWORKING = x"yes" -a x\$NFSD_START = x"yes"; then

	  if test -e /var/lib/nfs/.etab.lock -o -e /var/lib/nfs/.xtab.lock; then
	    echo "nfsd: is already running $rc_Err"
	    exit 1
	  fi

	  if ! checkproc /sbin/rpcbind; then
	    echo "/sbin/rpcbind: is not running \$rc_Err"
	    exit 1
	  fi

	  echo -n "Starting exportfs... "
	  exportfs -a
	  if test \$? != 0; then
	      echo "\$rc_Err"
	      exit 1
	  fi
	  echo "\$rc_Ok"

	  if test ! -f /proc/fs/nfsd/versions; then
	      modprobe -q sunrpc
	      modprobe -q nfsd
	      mount -t nfsd nfsd /proc/fs/nfsd
	  fi

	  if ! checkproc /usr/sbin/rpc.mountd; then
	      echo -n "Starting rpc.mountd daemon... "
	      rpc.mountd
	      if test \$? != 0; then
		  echo "\$rc_Err"
		  exit 1
	      fi
	      echo "\$rc_Ok"
	  fi

	  if ! checkproc /usr/sbin/rpc.statd; then
	      echo -n "Starting rpc.statd daemon... "
	      rpc.statd --no-notify
	      if test \$? != 0; then
		  echo "\$rc_Err"
		  exit 1
	      fi
	      echo "\$rc_Ok"
	  fi

	  echo -n "Starting rpc.nfsd daemon... "
	  rpc.nfsd
	  if test \$? != 0; then
	      echo "\$rc_Err"
	      exit 1
	  fi
	  echo "\$rc_Ok"
	else
	  \$0 stop
	fi
	;;
    stop)
	if test -e /var/lib/nfs/.etab.lock -o -e /var/lib/nfs/.xtab.lock; then
	  echo -n "Shut Down rpc.nfsd daemon... "
	  rpc.nfsd 0
	  if test \$? != 0; then
	      echo "\$rc_Err"
	  else
	      echo "\$rc_Ok"
	  fi
	  rm -f /var/lib/nfs/.etab.lock
	fi
	if checkproc /usr/sbin/rpc.statd; then
	    echo -n "Shut Down rpc.statd daemon... "
	    killproc rpc.statd
	    if test \$? != 0; then
		echo "\$rc_Err"
	    else
		echo "\$rc_Ok"
	    fi
	fi
	if checkproc /usr/sbin/rpc.mountd; then
	    echo -n "Shut Down rpc.mountd daemon... "
	    killproc rpc.mountd
	    if test \$? != 0; then
		echo "\$rc_Err"
	    else
		echo "\$rc_Ok"
	    fi
	fi
	;;
    restart)
	\$0 stop
	\$0 start
	;;
    *)
	echo "Usage: {start|stop|restart}"
	exit 1
	;;
esac

exit 0

EOF

  chmod 0740 /etc/init.d/nfsd

  pushd /etc/init.d/rc_net >/dev/null
    ln -s ../nfsd K10nfsd
    ln -s ../nfsd S82nfsd
  popd >/dev/null

fi


# ------------------- Files ------------------------------------------

%files
%{_sysconfdir}/defaults/nfs.conf
/sbin
%{_sbindir}/rpc.statd
%{_sbindir}/sm-notify
%{docdir}
%{_mandir}/man5/nfs.5.gz
%{_mandir}/man5/nfs.conf.5.gz
%{_mandir}/man8/mount.nfs.8.gz
%{_mandir}/man8/rpc.sm-notify.8.gz
%{_mandir}/man8/rpc.statd.8.gz
%{_mandir}/man8/sm-notify.8.gz
%{_mandir}/man8/statd.8.gz
%{_mandir}/man8/umount.nfs.8.gz
%{_localstatedir}/lib/nfs/sm
%{_localstatedir}/lib/nfs/sm.bak
%{_localstatedir}/lib/nfs/state

%files nfsd
%{_sysconfdir}/defaults/nfsmount.conf
%{_sbindir}/exportfs
%{_sbindir}/rpc.mountd
%{_sbindir}/rpc.nfsd
%{_sbindir}/showmount
%{_mandir}/man5/exports.5.gz
%{_mandir}/man5/nfsmount.conf.5.gz
%{_mandir}/man7/nfsd.7.gz
%{_mandir}/man8/exportfs.8.gz
%{_mandir}/man8/nfsd.8.gz
%{_mandir}/man8/mountd.8.gz
%{_mandir}/man8/rpc.mountd.8.gz
%{_mandir}/man8/rpc.nfsd.8.gz
%{_mandir}/man8/showmount.8.gz
%{_localstatedir}/lib/nfs/etab
%{_localstatedir}/lib/nfs/rmtab

%files tools
%{_sbindir}/nfsconf
%{_sbindir}/nfsstat
%{_sbindir}/rpcdebug
%{_mandir}/man8/nfsconf.8.gz
%{_mandir}/man8/nfsstat.8.gz
%{_mandir}/man8/rpcdebug.8.gz

%files python
%{_sbindir}/mountstats
%{_sbindir}/nfsiostat
%{_mandir}/man8/mountstats.8.gz
%{_mandir}/man8/nfsiostat.8.gz
